==> elgg-1.11.0.zip: elgg-1.11.0/mod/blog/languages/fr.php <==
<?php
return array(
	'blog' => 'Blogs',
	'blog:blogs' => 'Blogs',
	'blog:revisions' => 'Révisions',
	'blog:archives' => 'Archives',
	'blog:blog' => 'Blog',
	'item:object:blog' => 'Blogs',

	'blog:title:user_blogs' => 'Blogs de %s',
	'blog:title:all_blogs' => 'Tous les blogs du site',
	'blog:title:friends' => 'Blogs des contacts',

	'blog:group' => 'Blog du groupe',
	'blog:enableblog' => 'Activer le blog du groupe',
	'blog:write' => 'Écrire un article de blog',

	// Editing
	'blog:add' => 'Ajouter un article de blog',
	'blog:edit' => 'Modifier l\'article de blog',
	'blog:excerpt' => 'Extrait',
	'blog:body' => 'Corps de l\'article',
	'blog:save_status' => 'Dernier enregistrement:',
	
	'blog:revision' => 'Révision',
	'blog:auto_saved_revision' => 'Révision automatiquement enregistrée',

	// messages
	'blog:message:saved' => 'Article de blog enregistré.',
	'blog:error:cannot_save' => 'Impossible d\'enregistrer l\'article de blog.',
	'blog:error:cannot_auto_save' => 'Impossible de sauvegarder automatiquement l\'article de blog. ',
	'blog:error:cannot_write_to_container' => 'Droits d\'accès insuffisants pour enregistrer l\'article pour ce groupe.',
	'blog:messages:warning:draft' => 'Il y a un brouillon non enregistré de cet article !',
	'blog:edit_revision_notice' => '(Ancienne version)',
	'blog:message:deleted_post' => 'Article supprimé.',
	'blog:error:cannot_delete_post' => 'Impossible de supprimer l\'article.',
	'blog:none' => 'Aucun article de blog',
	'blog:error:missing:title' => 'Vous devez donner un titre à votre article !',
	'blog:error:missing:description' => 'Le corps de votre article est vide !',
	'blog:error:cannot_edit_post' => 'Cet article peut ne pas exister ou vous n\'avez pas les autorisations pour le modifier.',
	'blog:error:post_not_found' => 'Impossible de trouver l\'article de blog spécifié.',
	'blog:error:revision_not_found' => 'Impossible de trouver cette révision.',

	// river
	'river:create:object:blog' => '%s a publié un article de blog %s',
	'river:comment:object:blog' => '%s a commenté sur le blog %s',

	// notifications
	'blog:notify:summary' => 'Nouvel article de blog nommé %s',
	'blog:notify:subject' => 'Nouvel article de blog: %s',
	'blog:notify:body' =>
'
%s a publié un nouvel article de blog: %s

%s

Voir et commenter cet article de blog:
%s
',

	// widget
	'blog:widget:description' => 'Ce widget affiche vos derniers articles de blog',
	'blog:moreblogs' => 'Plus d\'articles de blog',
	'blog:numbertodisplay' => 'Nombre d\'articles de blog à afficher',
	'blog:noblogs' => 'Aucun article de blog'
);

==> elgg-1.12.12.zip: elgg-1.12.12/mod/blog/languages/fr.php <==
<?php
return array(
	'blog' => 'Blogs',
	'blog:blogs' => 'Blogs',
	'blog:revisions' => 'Révisions',
	'blog:archives' => 'Archives',
	'blog:blog' => 'Blog',
	'item:object:blog' => 'Article de blog',

	'blog:title:user_blogs' => 'Articles de blog de %s',
	'blog:title:all_blogs' => 'Tous les articles de blog du site',
	'blog:title:friends' => 'Articles de blog des contacts',

	'blog:group' => 'Blog du groupe',
	'blog:enableblog' => 'Activer le blog du groupe',
	'blog:write' => 'Écrire un article de blog',

	// Editing
	'blog:add' => 'Ajouter un article de blog',
	'blog:edit' => 'Modifier l\'article de blog',
	'blog:excerpt' => 'Extrait',
	'blog:body' => 'Corps de l\'article',
	'blog:save_status' => 'Dernier enregistrement :',
	
	'blog:revision' => 'Révision',
	'blog:auto_saved_revision' => 'Révision automatiquement enregistrée',

	// messages
	'blog:message:saved' => 'Article de blog enregistré.',
	'blog:error:cannot_save' => 'Impossible d\'enregistrer l\'article de blog.',
	'blog:error:cannot_auto_save' => 'Impossible de sauvegarder automatiquement l\'article de blog. ',
	'blog:error:cannot_write_to_container' => 'Droits d\'accès insuffisants pour enregistrer l\'article dans ce groupe.',
	'blog:messages:warning:draft' => 'Il y a un brouillon non enregistré de cet article !',
	'blog:edit_revision_notice' => '(Ancienne version)',
	'blog:message:deleted_post' => 'Article de blog supprimé.',
	'blog:error:cannot_delete_post' => 'Impossible de supprimer l\'article de blog.',
	'blog:none' => 'Aucun article de blog',
	'blog:error:missing:title' => 'Vous devez donner un titre à votre article !',
	'blog:error:missing:description' => 'Le corps de votre article est vide !',
	'blog:error:cannot_edit_post' => 'Cet article peut ne pas exister ou vous n\'avez pas les autorisations pour le modifier.',
	'blog:error:post_not_found' => 'Impossible de trouver l\'article de blog spécifié.',
	'blog:error:revision_not_found' => 'Impossible de trouver cette révision.',

	// river
	'river:create:object:blog' => '%s a publié un article de blog %s',
	'river:comment:object:blog' => '%s a commenté l\'article de blog %s',

	// notifications
	'blog:notify:summary' => 'Nouvel article de blog intitulé %s',
	'blog:notify:subject' => 'Nouvel article de blog : %s',
	'blog:notify:body' =>
'
%s a publié un nouvel article de blog : %s

%s

Voir et commenter cet article de blog :
%s
',

	// widget
	'blog:widget:description' => 'Ce widget affiche vos derniers articles de blog',
	'blog:moreblogs' => 'Plus d\'articles de blog',
	'blog:numbertodisplay' => 'Nombre d\'articles de blog à afficher',
	'blog:noblogs' => 'Aucun article de blog'
);
